\name{plot3D.splmm}
\alias{plot3D.splmm}
\title{3D Plot the tuning results of a \code{'splmm.tuning'} object when tuning over both lambda 1 and lambda 2 grids}
\description{This function inputs an \code{'splmm.tuning'} object and plot the model selection criterion values in a 3D plot over the lambda 1 and lambda 2 tuning parameters grid.}
\usage{
\method{plot3D}{splmm}(x, criteria=c("BIC","AIC"),...)
}

\arguments{
  \item{x}{a \code{'splmm.tuning'} object with both \code{lam1.tuning=TRUE} and \code{lam2.tuning=TRUE}}
  \item{criteria}{A parameter specifying whether the criteria value the user want to plot is \code{BIC} or \code{AIC}. The default is \code{BIC}}
  \item{\dots}{not used}
}


%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{plot3D}
}
\examples{

\donttest{
data(cognitive)

x <- model.matrix(ravens ~ schoolid+treatment+relyear+sex+age_at_time0+height
+weight+head_circ+ses1+readtest+writetest+yrsofsch, cognitive)
z <- model.matrix(ravens ~ schoolid+treatment+relyear, cognitive)

## Tuning over lambda1 grid and lambda2 grid
lam1 = seq(0.01,0.05,0.01)
lam2 = seq(0.01,0.05,0.01)
fit1 <-splmmTuning(x=x,y=cognitive$ravens,z=z,grp=cognitive$id,lam1=lam1,
lam2=lam2,penalty.b="scad", penalty.L="scad")
plot3D(fit1)
}

}

